@@ -61,7 +61,9 @@ List param_get(CharacterVector urls, CharacterVector parameter_names){
 //'@param value a value to associate with the key. This can be a single string,
 //'or a vector the same length as \code{urls}
 //'
-//'@return the original vector of URLs, but with modified/inserted key-value pairs.
+//'@return the original vector of URLs, but with modified/inserted key-value pairs. If the
+//'URL is \code{NA}, the returned value will be - if the key or value are, no insertion
+//'will be made.
 //'
 //'@examples
 //'# Set a URL parameter where there's already a key for that
@@ -75,7 +77,7 @@ List param_get(CharacterVector urls, CharacterVector parameter_names){
 //'
 //'@export
 //[[Rcpp::export]]
-std::vector < std::string > param_set(std::vector < std::string > urls, std::string key, std::vector < std::string > value){
+CharacterVector param_set(CharacterVector urls, String key, CharacterVector value){
   parameter p_inst;
   return p_inst.set_parameter_vectorised(urls, key, value);
 }
@@ -91,6 +93,8 @@ std::vector < std::string > param_set(std::vector < std::string > urls, std::str
 //'@param keys a vector of parameter keys to remove.
 //'
 //'@return the original URLs but with the key/value pairs specified by \code{keys} removed.
+//'If the original URL is \code{NA}, \code{NA} will be returned; if a specified key is \code{NA},
+//'nothing will be done with it.
 //'
 //'@seealso \code{\link{param_set}} to modify values associated with keys, or \code{\link{param_get}}
 //'to retrieve those values.
@@ -101,7 +105,7 @@ std::vector < std::string > param_set(std::vector < std::string > urls, std::str
 //'             keys = c("action","format"))
 //'@export
 //[[Rcpp::export]]
-std::vector < std::string > param_remove(std::vector < std::string > urls, std::vector < std::string > keys){
+CharacterVector param_remove(CharacterVector urls, CharacterVector keys){
   parameter p_inst;
   return p_inst.remove_parameter_vectorised(urls, keys);
   
